==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.md <==
# AmazonCloudFrontFunctions


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')
```



| Illustration | AmazonCloudFrontFunctions | AmazonCloudFrontFunctionsCard | AmazonCloudFrontFunctionsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.png) | ![illustration for AmazonCloudFrontFunctions](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.Local.png) | ![illustration for AmazonCloudFrontFunctionsCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctionsCard.Local.png) | ![illustration for AmazonCloudFrontFunctionsGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctionsGroup.Local.png) |




## AmazonCloudFrontFunctions

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctions
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctions('AmazonCloudFrontFunctions', 'Amazon Cloud Front Functions', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctions
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctions('AmazonCloudFrontFunctions', 'Amazon Cloud Front Functions', 'an optional tech label')
@enduml
```

## AmazonCloudFrontFunctionsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsCard('AmazonCloudFrontFunctionsCard', 'Amazon Cloud Front Functions Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsCard('AmazonCloudFrontFunctionsCard', 'Amazon Cloud Front Functions Card', 'an optional description')
@enduml
```

## AmazonCloudFrontFunctionsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsGroup('AmazonCloudFrontFunctionsGroup', 'Amazon Cloud Front Functions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsGroup('AmazonCloudFrontFunctionsGroup', 'Amazon Cloud Front Functions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.md <==
# AmazonCloudFrontFunctions


```text
aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions
```

```text
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')
```



| Illustration | AmazonCloudFrontFunctions | AmazonCloudFrontFunctionsCard | AmazonCloudFrontFunctionsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.png) | ![illustration for AmazonCloudFrontFunctions](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions.Local.png) | ![illustration for AmazonCloudFrontFunctionsCard](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctionsCard.Local.png) | ![illustration for AmazonCloudFrontFunctionsGroup](../../../aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctionsGroup.Local.png) |




## AmazonCloudFrontFunctions

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctions
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctions('AmazonCloudFrontFunctions', 'Amazon Cloud Front Functions', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctions
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctions('AmazonCloudFrontFunctions', 'Amazon Cloud Front Functions', 'an optional tech label', 'an optional description')
@enduml
```

## AmazonCloudFrontFunctionsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsCard('AmazonCloudFrontFunctionsCard', 'Amazon Cloud Front Functions Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsCard
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsCard('AmazonCloudFrontFunctionsCard', 'Amazon Cloud Front Functions Card', 'an optional description')
@enduml
```

## AmazonCloudFrontFunctionsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsGroup('AmazonCloudFrontFunctionsGroup', 'Amazon Cloud Front Functions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AmazonCloudFrontFunctionsGroup
include('aws-q2-2022/Resource/NetworkingAndContentDelivery/AmazonCloudFrontFunctions')

' renders the element
AmazonCloudFrontFunctionsGroup('AmazonCloudFrontFunctionsGroup', 'Amazon Cloud Front Functions Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
